@@ -30,4 +30,4 @@ gboolean InsertAsciiCharacterClick (GtkWidget *widget, gpointer gdata);
 }
 #endif /* __cplusplus */
 
-#endif ASCIISELECT
\ No newline at end of file
+#endif /* ASCIISELECT */
