@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.9 2000/05/18 00:30:59 hovinen Exp $ */
+/* $Id: dict.c,v 1.10 2000/05/21 23:59:35 kmaraas Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -27,6 +27,7 @@
 #include <unistd.h>
 
 #include <glib.h>
+#include <gnome.h>
 
 #include "dict.h"
 
@@ -619,7 +620,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
         if (context->command->error_notify_cb)
 	    context->command->error_notify_cb (context->command, 
 					       DICT_SOCKET_ERROR,
-					       "Cannot connect to server",
+					       _("Cannot connect to server"),
 					       context->command->user_data);
         dict_disconnect (context);
     }
