@@ -1,4 +1,4 @@
-/* $Id: gdict-pref-dialog.c,v 1.4 2000/05/18 00:28:11 hovinen Exp $ */
+/* $Id: gdict-pref-dialog.c,v 1.5 2000/05/21 23:59:35 kmaraas Exp $ */
 
 /*
  *  Mike Hughes <mfh@psilord.com>
@@ -202,7 +202,7 @@ gdict_pref_dialog_init (GDictPrefDialog *pref_dialog) {
     gtk_table_set_col_spacings (GTK_TABLE (table), 4);
     
     for (i = 0; i < NUM_TYPEFACES; i++) {
-        label = gtk_label_new (typeface_sel_names[i]);
+        label = gtk_label_new (_(typeface_sel_names[i]));
         gtk_table_attach (GTK_TABLE (table), label, 
                           (3 * (i / NUM_TYPEFACE_ROWS)), 
                           (3 * (i / NUM_TYPEFACE_ROWS)) + 1,
