@@ -36,7 +36,7 @@ extern int errno;
 
 static GFloppy floppy;
 static GladeXML *xml;
-
+static GtkWidget *toplevel = NULL;
 static gint
 option_menu_get_history (GtkOptionMenu *option_menu)
 {
@@ -74,7 +74,7 @@ start_format ()
 	close (floppy.message [1]);
 
 	fcntl (floppy.message [0], F_SETFL, O_NONBLOCK);
-	setup_progress_and_run (&floppy, glade_xml_get_widget (xml, "toplevel"));
+	setup_progress_and_run (&floppy, toplevel);
 }
 
 static void
@@ -150,10 +150,16 @@ set_floppy_extended_device ()
 	}
 }
 
+gint
+on_toplevel_delete_event (GtkWidget *w, GdkEventAny *e, gpointer data)
+{
+	toplevel = NULL;
+	return TRUE;
+}
+
 int
 main (int argc, char *argv[])
 {
-	GtkWidget *toplevel;
 	GtkWidget *ext2_entry;
 	GtkWidget *type_option;
 	GtkWidget *icon_frame;
@@ -190,8 +196,10 @@ main (int argc, char *argv[])
 	quick_format_button = glade_xml_get_widget (xml, "quick_format_button");
 	icon_frame = glade_xml_get_widget (xml, "icon_frame");
 	type_option = glade_xml_get_widget (xml, "type_option");
-
-	icon = gnome_pixmap_new_from_file ("/usr/share/pixmaps/mc/i-floppy.png");
+	toplevel = glade_xml_get_widget (xml, "toplevel");
+	glade_xml_signal_autoconnect (xml);
+	
+	icon = gnome_pixmap_new_from_file (GNOME_ICONDIR"/mc/i-floppy.png");
 	gtk_container_add (GTK_CONTAINER (icon_frame), icon);
 	gtk_widget_show (icon);
 	/* We do this to get around a bug in libglade.  Ideally we won't need
@@ -214,8 +222,10 @@ main (int argc, char *argv[])
 		gtk_widget_show (ext2_entry);
 	}
 
-	while ((button = gnome_dialog_run (GNOME_DIALOG (toplevel))) != 1) {
+	while ((button = gnome_dialog_run (GNOME_DIALOG (toplevel))) >= 0) {
 		GtkWidget *density_option;
+		if (button == 1 ) 
+			break;
 
 		if (button == 2) {
 			GnomeHelpMenuEntry ref = {"gfloppy", "index.html"};
@@ -238,6 +248,8 @@ main (int argc, char *argv[])
 		floppy.quick_format = GTK_TOGGLE_BUTTON (quick_format_button)->active;
 
 		start_format ();
+		if (!toplevel)
+			break;
 		gtk_widget_set_sensitive (toplevel, TRUE);
 		if (gnome_dialog_run (GNOME_DIALOG (gnome_question_dialog_parented (_("Format another floppy?"),
 										    NULL, NULL,
@@ -247,3 +259,6 @@ main (int argc, char *argv[])
 	return 0;
 }
 
+
+
+
