@@ -128,7 +128,8 @@ read_stdinput (gpointer data,
 		g_free (error_label);
 		error_label = NULL;
 
-		gnome_dialog_set_parent (GNOME_DIALOG (error_dialog), GTK_WINDOW (progress_dialog));
+		if (progress_dialog)
+			gnome_dialog_set_parent (GNOME_DIALOG (error_dialog), GTK_WINDOW (progress_dialog));
 		w = GNOME_DIALOG (error_dialog)->vbox;
 		w = ((GtkBoxChild *) GTK_BOX (w)->children->data)->widget;
 	        w = ((GtkBoxChild *) GTK_BOX (w)->children->next->data)->widget;
@@ -160,7 +161,6 @@ progress_cancel_callback (GtkWidget *progress, gpointer data)
 	GFloppy *floppy = (GFloppy *) data;
 
 	kill (floppy->pid, SIGTERM);
-	gtk_signal_disconnect_by_func (GTK_OBJECT (progress), progress_destroy_callback, data);
 	gtk_widget_destroy (progress_dialog);
 	progress_dialog = NULL;
 
@@ -181,9 +181,7 @@ setup_progress_and_run (GFloppy *floppy, GtkWidget *parent)
 	gtk_widget_show (msg_label);
 	progressbar = gtk_progress_bar_new ();
 	gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (progress_dialog)->vbox), progressbar, FALSE, FALSE, 0);
-	floppy->handler_id = gdk_input_add (floppy->message[0], GDK_INPUT_READ,        read_stdinput, floppy);
-
-	gtk_widget_show_all (progress_dialog);
+	floppy->handler_id = gdk_input_add (floppy->message[0], GDK_INPUT_READ, read_stdinput, floppy);
 
 	gtk_signal_connect (GTK_OBJECT (progress_dialog), "destroy", progress_destroy_callback, floppy);
 	gnome_dialog_button_connect (GNOME_DIALOG (progress_dialog), 0, progress_cancel_callback, floppy);
