@@ -51,6 +51,7 @@ void change_log_menu (GtkWidget * widget, gpointer user_data);
 void CalendarMenu (GtkWidget * widget, gpointer user_data);
 void MonitorMenu (GtkWidget* widget, gpointer user_data); 
 void create_zoom_view (GtkWidget * widget, gpointer user_data);
+void UserPrefsDialog(GtkWidget * widget, gpointer user_data);
 void AboutShowWindow (GtkWidget* widget, gpointer user_data);
 void CloseApp ();
 void CloseLog (Log *);
@@ -112,6 +113,9 @@ GnomeUIInfo view_menu[] = {
         {GNOME_APP_UI_ITEM, N_("Zoom                    "), 
 	 N_("Show line info"), create_zoom_view, NULL, NULL,
          GNOME_APP_PIXMAP_NONE, NULL, 'Z', GDK_CONTROL_MASK, NULL},
+        {GNOME_APP_UI_ITEM, N_("Preferences...          "), 
+	 N_("Show user preferences"), UserPrefsDialog, NULL, NULL,
+         GNOME_APP_PIXMAP_NONE, NULL, 'P', GDK_CONTROL_MASK, NULL},
         {GNOME_APP_UI_ENDOFINFO, NULL, NULL, NULL}
 };
 
@@ -155,6 +159,8 @@ GtkWidget *main_win_scrollbar;
 GtkLabel *filename_label, *date_label;
 
 GList *regexp_db, *descript_db, *actions_db;
+UserPrefsStruct *user_prefs;
+UserPrefsStruct user_prefs_struct;
 ConfigData *cfg;
 int open_log_visible;
 
@@ -221,6 +227,8 @@ InitApp ()
   /*  Initialize variables */
   loginfovisible = FALSE;
   regexp_db = NULL;
+  user_prefs = &user_prefs_struct;
+  SetDefaultUserPrefs(user_prefs);
 
   /* Read databases */
   open_databases ();
@@ -301,9 +309,9 @@ CreateMainWin ()
    gtk_widget_show (w);
                
    canvas = gtk_drawing_area_new ();
-   //gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, LOG_CANVAS_H); 
+   /*gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, LOG_CANVAS_H); */
    gtk_drawing_area_size (GTK_DRAWING_AREA (canvas), 2*LOG_CANVAS_W, 10); 
-   //gtk_widget_set_usize ( GTK_WIDGET (canvas), LOG_CANVAS_W, LOG_CANVAS_H);
+   /*gtk_widget_set_usize ( GTK_WIDGET (canvas), LOG_CANVAS_W, LOG_CANVAS_H);*/
    gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW (w), canvas);
    gtk_box_pack_start (GTK_BOX(hbox), w, TRUE, TRUE, 0);
 
@@ -453,7 +461,7 @@ MainWinScrolled (GtkAdjustment *adjustment, GtkRange *range)
    return;
 
  if (newln >= curlog->lstats.numlines)
-   newln == curlog->lstats.numlines - 1;
+   newln = curlog->lstats.numlines - 1;
 
   /* Find mark which has this line */
   mark = curlog->curmark;
@@ -812,3 +820,13 @@ IsLeapYear (int year)
    else
       return FALSE;
 }
+
+void SetDefaultUserPrefs(UserPrefsStruct *prefs)
+{
+	/* Make defaults configurable later */
+	/* Will have to save prefs. eventually too*/
+
+	prefs->process_column_width = 12;
+	prefs->hostname_column_width = 15;
+	prefs->message_column_width = 24;
+}
