@@ -1,3 +1,4 @@
+#include <config.h>
 #include <stdio.h>
 #include <gnome.h>
 #include <glade/glade.h>
@@ -207,7 +208,7 @@ view_color_list_new (MDIColorGeneric *mcg)
   view_color_list_set_sort_column (VIEW_COLOR_LIST (object), COLUMN_PIXMAP,
 				   GTK_SORT_ASCENDING);
 
-//  gtk_clist_set_auto_sort (cl, TRUE);
+  /*  gtk_clist_set_auto_sort (cl, TRUE); */
 
   gtk_clist_column_titles_active (cl);
   gtk_clist_set_use_drag_icons (cl, 0);
@@ -398,7 +399,7 @@ view_color_list_button_press (GtkCList *clist, GdkEventButton *event,
 	  gtk_clist_thaw (clist);
 	}      
 	
-	menu_view_do_popup (event);
+	menu_view_do_popup (event, VIEW_COLOR_GENERIC (vcl));
 	return FALSE;
       }
     }
